/**
 * @file capture.h
 * Interface for capturing still frames
 * @author Marko Mkel (msmakela@nic.funet.fi)
 */

/*
 * Copyright  2004 Marko Mkel
 * 
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 * 
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 * 
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/** Set up the camera for capturing frames
 * @param dev	the device descriptor name
 * @return	zero on success, nonzero on failure
 */
int
capture_init (const char* dev);

/** Clean up the camera after capturing frames */
void
capture_fini (void);

/** Capture a frame
 * @param com	(output) image comment, NUL terminated
 * @param size	maximum length of the comment buffer, including terminating NUL
 * @return	pointer to frame data, or NULL on failure
 */
const char*
capture_do (char* com,
	    size_t size);

/** Done with a frame */
void
capture_done (void);
