/**
 * @file lens.h
 * Lens distortion parameteres
 * @author Marko Mkel (msmakela@nic.funet.fi)
 */

/* The following parameters are for ADS Pyro Webcam API-203.
 * For other cameras, first define LENS_SQUARE and LENS_QUAD to 0,
 * and make a picture of graphing paper or some other suitable object.
 * Then find the parameters with the Gimp "wideangle" plugin, and
 * fill them in here.
 */

/** @name These parameters correspond to the parameters of the
 * Gimp "wideangle" plugin by David Hodson.
 */
/**@{*/
/** r^2 correction factor (Main / 200).  The neutral value is 0. */
#define LENS_SQUARE	((double) -27.0 / 200.0)
/** r^4 correction factor (Edge / 200).  The neutral value is 0. */
#define LENS_QUAD	((double) 8.0 / 200.0)
/**@}*/

/** @name Optional parameters.  For best performance, these should
 * be left undefined when equal to the neutral value. */
/**@{*/
/** Image scaling factor (0.5^(Zoom / 100)).
 * The neutral values are Zoom=0, or LENS_SCALE=1. */
#define LENS_SCALE	1.045
/** Image brightening factor (Brighten / 10).  The neutral value is 0.*/
/* #define LENS_BRIGHT	((double) 0.0 / -10.0) */
/**@}*/
